pub fn layout(el: &Element, bounds: Rect, font: Option<&Font>) -> LayoutNodeExpand description
Lay el out within bounds, producing a retained LayoutNode tree with
absolute bounds, decorations, text content, and action handles.
pub fn layout(el: &Element, bounds: Rect, font: Option<&Font>) -> LayoutNodeLay el out within bounds, producing a retained LayoutNode tree with
absolute bounds, decorations, text content, and action handles.