pub struct ViewportId(pub u32);Expand description
A caller-chosen handle to an embedded-content viewport — a rectangle the
app fills with externally-rendered pixels (a browser page, video frame, or a
sandboxed content process’s GPU surface). Unlike the auto-registered handler
ids, the value is chosen by the app so it stays stable across frames and can
be correlated with the content source that feeds it (see
Element::viewport).
Tuple Fields
0: u32Trait Implementations
Sourceimpl Clone for ViewportId
impl Clone for ViewportId
Sourcefn clone(&self) -> ViewportId
fn clone(&self) -> ViewportId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ViewportId
Sourceimpl Debug for ViewportId
impl Debug for ViewportId
impl Eq for ViewportId
Sourceimpl Hash for ViewportId
impl Hash for ViewportId
Sourceimpl Ord for ViewportId
impl Ord for ViewportId
Sourcefn cmp(&self, other: &ViewportId) -> Ordering
fn cmp(&self, other: &ViewportId) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ViewportId
impl PartialEq for ViewportId
Sourcefn eq(&self, other: &ViewportId) -> bool
fn eq(&self, other: &ViewportId) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ViewportId
impl PartialOrd for ViewportId
impl StructuralPartialEq for ViewportId